@@ -1,9 +1,10 @@
 package Log::Any::Plugin::Util;
 # ABSTRACT: Utilities for Log::Any::Plugin classes
-$Log::Any::Plugin::Util::VERSION = '0.003';
+$Log::Any::Plugin::Util::VERSION = '0.004';
 use strict;
 use warnings;
 use Carp qw(croak);
+use Log::Any qw();
 
 use base qw(Exporter);
 
@@ -11,6 +12,7 @@ our @EXPORT_OK = qw(
     get_old_method
     set_new_method
     get_class_name
+    all_logging_methods
 );
 
 sub get_old_method {
@@ -33,6 +35,12 @@ sub get_class_name {
                                       : 'Log::Any::Plugin::' . $name;
 }
 
+sub all_logging_methods {
+    my ($class) = @_;
+
+    return ( Log::Any->logging_methods, Log::Any->log_level_aliases );
+}
+
 1;
 
 __END__
@@ -47,7 +55,7 @@ Log::Any::Plugin::Util - Utilities for Log::Any::Plugin classes
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 DESCRIPTION
 
@@ -55,7 +63,7 @@ These functions are only of use to authors of Log::Any::Plugin classes.
 
 Users should see Log::Any::Plugin instead.
 
-=head1 FUNCTIONS
+=head1 CLASS METHODS
 
 =head2 get_old_method ( $class, $method_name )
 
@@ -95,6 +103,10 @@ Either a namespace suffix, or a fully-qualified class name prefixed with '+'.
 
 =back
 
+=head2 all_logging_methods
+
+Return an array of all the Log:Any logging methods and aliases
+
 =head1 SEE ALSO
 
 L<Log::Any::Plugin>
